---
layout: doc
weight: 1
title: Build
categories: developers
permalink: /developers/build/
---

You can build the source code yourself after making any modifications. 

First you should install `nodejs` and `npm`, then first run this command: 

```
npm install
```

to install all dependencies.

Now you can run this command to minify all static resources:

```
make build
```
